package cz.zweistein.df.soundsense;

import java.io.IOException;
import java.util.logging.Logger;
import java.util.regex.Pattern;

import cz.zweistein.df.soundsense.config.Sound;
import cz.zweistein.df.soundsense.config.SoundsXML;
import cz.zweistein.df.soundsense.log.LogReader;
import cz.zweistein.df.soundsense.player.PlayerManager;
import cz.zweistein.df.soundsense.util.LoggerSource;

public class SoundSense {
	private static Logger logger = LoggerSource.logger;
	
	public static void main(String[] args) {
		
		try {
			
			String logFile = "../gamelog.txt";
			String soundsConfig = "./packs/";
			
			if (args.length > 0) {
				logFile = args[0];
			}
			if (args.length > 1) {
				soundsConfig = args[1];
			}
			
			logger.info("SoundSense for Dwarf Fortress is starting...");
			logger.info("Loading theme packs from "+soundsConfig);
			SoundsXML soundsXML = new SoundsXML(soundsConfig);
			logger.info("Done loading "+soundsConfig+", loaded "+soundsXML.getSounds().size()+" items.");
			
			PlayerManager player = new PlayerManager();
			
			logger.info("Attempting to listen to "+logFile);
			LogReader logReader = new LogReader(logFile);
			logger.info("Listening to "+logFile);
			
			while (true) {
				String nextLine = logReader.getNextLine();
				
				logger.info("New message: "+nextLine);
				
				for (Sound sound: soundsXML.getSounds()) {
					
					if (Pattern.matches(sound.getLogPattern(), nextLine)) {
						player.playSound(sound);
						break;
					}
				}
				
			}
			
		} catch (IOException e) {
			logger.severe(e.toString());
		}
		
	}

}
